@@ -66,6 +66,7 @@ from sunpy.time import parse_time
 from sunpy import config
 from sunpy import lightcurve
 from sunpy.util.net import check_download_file
+from sunpy.util.config import get_and_create_download_dir
 from sunpy import sun
 
 GOES_CONVERSION_DICT = {'X': u.Quantity(1e-4, "W/m^2"),
@@ -86,8 +87,6 @@ try:
 except socket.gaierror:
     HOST = ''
 GOES_REMOTE_PATH = "http://{0}/ssw/gen/idl/synoptic/goes/".format(HOST)
-# Define location where data files should be downloaded to.
-DATA_PATH = config.get("downloads", "download_dir")
 # Define variables for file names
 FILE_TEMP_COR = "goes_chianti_temp_cor.csv"
 FILE_TEMP_PHO = "goes_chianti_temp_pho.csv"
@@ -254,7 +253,7 @@ def calculate_temperature_em(goeslc, abundances="coronal",
     if not isinstance(goeslc, lightcurve.LightCurve):
         raise TypeError("goeslc must be a LightCurve object.")
     if not download_dir:
-        download_dir = DATA_PATH
+        download_dir = get_and_create_download_dir()
 
     # Find temperature and emission measure with _goes_chianti_tem
     temp, em = _goes_chianti_tem(
@@ -375,7 +374,7 @@ def _goes_chianti_tem(longflux, shortflux, satellite=8,
 
     """
     if not download_dir:
-        download_dir = DATA_PATH
+        download_dir = get_and_create_download_dir()
     # ENSURE INPUTS ARE OF CORRECT TYPE AND VALID VALUES
     longflux = longflux.to(u.W/u.m/u.m)
     shortflux = shortflux.to(u.W/u.m/u.m)
@@ -511,7 +510,7 @@ def _goes_get_chianti_temp(fluxratio, satellite=8, abundances="coronal",
 
     """
     if not download_dir:
-        download_dir = DATA_PATH
+        download_dir = get_and_create_download_dir()
     # If download kwarg is True, or required data files cannot be
     # found locally, download required data files.
     check_download_file(FILE_TEMP_COR, GOES_REMOTE_PATH, download_dir,
@@ -544,7 +543,7 @@ def _goes_get_chianti_temp(fluxratio, satellite=8, abundances="coronal",
     label = "ratioGOES{0}".format(satellite)
     # Read data representing appropriate temperature--flux ratio
     # relationship depending on satellite number and assumed abundances.
-    with open(os.path.join(DATA_PATH, data_file), "r") as csvfile:
+    with open(os.path.join(get_and_create_download_dir(), data_file), "r") as csvfile:
         startline = dropwhile(lambda l: l.startswith("#"), csvfile)
         csvreader = csv.DictReader(startline, delimiter=";")
         for row in csvreader:
@@ -555,7 +554,7 @@ def _goes_get_chianti_temp(fluxratio, satellite=8, abundances="coronal",
 
     # Ensure input values of flux ratio are within limits of model table
     if np.min(fluxratio) < np.min(modelratio) or \
-      np.max(fluxratio) > np.max(modelratio):
+       np.max(fluxratio) > np.max(modelratio):
         raise ValueError(
             "For GOES {0}, all values in fluxratio input must be within " +
             "the range {1} - {2}.".format(satellite, np.min(modelratio),
@@ -667,7 +666,7 @@ def _goes_get_chianti_em(longflux, temp, satellite=8, abundances="coronal",
 
     """
     if not download_dir:
-        download_dir = DATA_PATH
+        download_dir = get_and_create_download_dir()
     # If download kwarg is True, or required data files cannot be
     # found locally, download required data files.
     check_download_file(FILE_EM_COR, GOES_REMOTE_PATH, download_dir,
@@ -699,7 +698,7 @@ def _goes_get_chianti_em(longflux, temp, satellite=8, abundances="coronal",
 
     # Initialize lists to hold model data of temperature - long channel
     # flux relationship read in from csv file.
-    modeltemp = [] # modelled temperature is in log_10 space in units of MK
+    modeltemp = []   # modelled temperature is in log_10 space in units of MK
     modelflux = []
     # Determine name of column in csv file containing model ratio values
     # for relevant GOES satellite
@@ -707,7 +706,7 @@ def _goes_get_chianti_em(longflux, temp, satellite=8, abundances="coronal",
 
     # Read data representing appropriate temperature--long flux
     # relationship depending on satellite number and assumed abundances.
-    with open(os.path.join(DATA_PATH, data_file), "r") as csvfile:
+    with open(os.path.join(get_and_create_download_dir(), data_file), "r") as csvfile:
         startline = dropwhile(lambda l: l.startswith("#"), csvfile)
         csvreader = csv.DictReader(startline, delimiter=";")
         for row in csvreader:
@@ -718,8 +717,8 @@ def _goes_get_chianti_em(longflux, temp, satellite=8, abundances="coronal",
 
     # Ensure input values of flux ratio are within limits of model table
     if np.min(log10_temp) < np.min(modeltemp) or \
-      np.max(log10_temp) > np.max(modeltemp) or \
-      np.isnan(np.min(log10_temp)):
+       np.max(log10_temp) > np.max(modeltemp) or \
+       np.isnan(np.min(log10_temp)):
         raise ValueError("All values in temp must be within the range "
                          "{0} - {1} MK.".format(np.min(10**modeltemp),
                                                 np.max(10**modeltemp)))
@@ -831,7 +830,7 @@ def calculate_radiative_loss_rate(goeslc, force_download=False,
 
     """
     if not download_dir:
-        download_dir = DATA_PATH
+        download_dir = get_and_create_download_dir()
     # Check that input argument is of correct type
     if not isinstance(goeslc, lightcurve.LightCurve):
         raise TypeError("goeslc must be a LightCurve object.")
@@ -861,6 +860,7 @@ def calculate_radiative_loss_rate(goeslc, force_download=False,
 
     return lc_new
 
+
 @u.quantity_input(temp=u.MK, em=u.cm**(-3))
 def _calc_rad_loss(temp, em, obstime=None, force_download=False,
                    download_dir=None):
@@ -945,7 +945,7 @@ def _calc_rad_loss(temp, em, obstime=None, force_download=False,
     <Quantity [  3.01851392e+19,  3.01851392e+19] J / s>
     """
     if not download_dir:
-        download_dir = DATA_PATH
+        download_dir = get_and_create_download_dir()
     # Check inputs are correct
     temp = temp.to(u.K)
     em = em.to(1/u.cm**3)
@@ -958,12 +958,12 @@ def _calc_rad_loss(temp, em, obstime=None, force_download=False,
 
     # Initialize lists to hold model data of temperature - rad loss rate
     # relationship read in from csv file
-    modeltemp = [] # modelled temperature is in log_10 space in units of MK
+    modeltemp = []    # modelled temperature is in log_10 space in units of MK
     model_loss_rate = []
 
     # Read data from csv file into lists, being sure to skip commented
     # lines beginning with "#"
-    with open(os.path.join(DATA_PATH, FILE_RAD_COR),
+    with open(os.path.join(get_and_create_download_dir(), FILE_RAD_COR),
               "r") as csvfile:
         startline = csvfile.readlines()[7:]
         csvreader = csv.reader(startline, delimiter=" ")
@@ -974,7 +974,7 @@ def _calc_rad_loss(temp, em, obstime=None, force_download=False,
     model_loss_rate = np.asarray(model_loss_rate)
     # Ensure input values of flux ratio are within limits of model table
     if temp.value.min() < modeltemp.min() or \
-        temp.value.max() > modeltemp.max():
+    temp.value.max() > modeltemp.max():
         raise ValueError("All values in temp must be within the range " +
                          "{0} - {1} MK.".format(np.min(modeltemp/1e6),
                                                 np.max(modeltemp/1e6)))
@@ -994,7 +994,7 @@ def _calc_rad_loss(temp, em, obstime=None, force_download=False,
         if len(obstime) != n:
             raise IOError("obstime must have same number of elements as "
                           "temp and em.")
-        if type(obstime) == pandas.tseries.index.DatetimeIndex:
+        if type(obstime) == pandas.DatetimeIndex:
             obstime = obstime.to_pydatetime
         if any(type(obst) == str for obst in obstime):
             parse_time(obstime)
@@ -1019,11 +1019,11 @@ def _calc_rad_loss(temp, em, obstime=None, force_download=False,
         rad_loss_cumul = cumtrapz(rad_loss, obstime_seconds)
         rad_loss_cumul = u.Quantity(rad_loss_cumul, unit=rad_loss.unit*u.s)
         # Enter results into output dictionary.
-        rad_loss_out = {"rad_loss_rate":rad_loss,
-                        "rad_loss_cumul" : rad_loss_cumul,
-                        "rad_loss_int":rad_loss_int}
+        rad_loss_out = {"rad_loss_rate": rad_loss,
+                        "rad_loss_cumul": rad_loss_cumul,
+                        "rad_loss_int": rad_loss_int}
     else:
-        rad_loss_out = {"rad_loss_rate":rad_loss}
+        rad_loss_out = {"rad_loss_rate": rad_loss}
 
     return rad_loss_out
 
@@ -1194,7 +1194,7 @@ def _goes_lx(longflux, shortflux, obstime=None, date=None):
         if not len(longflux) == len(shortflux) == len(obstime):
             raise ValueError("longflux, shortflux, and obstime must all have "
                              "same number of elements.")
-        if type(obstime) == pandas.tseries.index.DatetimeIndex:
+        if type(obstime) == pandas.DatetimeIndex:
             obstime = obstime.to_pydatetime
         if any(type(obst) == str for obst in obstime):
             parse_time(obstime)
@@ -1223,15 +1223,16 @@ def _goes_lx(longflux, shortflux, obstime=None, date=None):
         shortlum_cumul = cumtrapz(shortlum.value, obstime_seconds)
         shortlum_cumul = u.Quantity(shortlum_cumul,
                                     unit=shortlum.unit*u.s)
-        lx_out = {"longlum":longlum, "shortlum":shortlum,
-                  "longlum_cumul":longlum_cumul,
-                  "shortlum_cumul":shortlum_cumul,
-                  "longlum_int":longlum_int, "shortlum_int":shortlum_int}
+        lx_out = {"longlum": longlum, "shortlum": shortlum,
+                  "longlum_cumul": longlum_cumul,
+                  "shortlum_cumul": shortlum_cumul,
+                  "longlum_int": longlum_int, "shortlum_int": shortlum_int}
     else:
-        lx_out = {"longlum":longlum, "shortlum":shortlum}
+        lx_out = {"longlum": longlum, "shortlum": shortlum}
 
     return lx_out
 
+
 @u.quantity_input(flux=u.W/u.m/u.m)
 def _calc_xraylum(flux, date=None):
     """
@@ -1303,13 +1304,13 @@ def flareclass_to_flux(flareclass):
     >>> flareclass_to_flux('X2.4')
     0.00024 W / m2
     """
-    if type(flareclass) != type('str'):
+    if not isinstance(flareclass, type('str')):
         raise TypeError("Input must be a string")
-    #TODO should probably make sure the string is in the expected format.
+    # TODO should probably make sure the string is in the expected format.
 
     flareclass = flareclass.upper()
-    #invert the conversion dictionary
-    #conversion_dict = {v: k for k, v in GOES_CONVERSION_DICT.items()}
+    # invert the conversion dictionary
+    # conversion_dict = {v: k for k, v in GOES_CONVERSION_DICT.items()}
     return float(flareclass[1:]) * GOES_CONVERSION_DICT[flareclass[0]]
 
 @u.quantity_input(goesflux=u.watt/u.m**2)
@@ -1355,7 +1356,7 @@ def flux_to_flareclass(goesflux):
         raise ValueError("Flux cannot be negative")
 
     decade = np.floor(np.log10(goesflux.to('W/m**2').value))
-    #invert the conversion dictionary
+    # invert the conversion dictionary
     conversion_dict = {v: k for k, v in GOES_CONVERSION_DICT.items()}
     if decade < -8:
         str_class = "A"
@@ -1364,6 +1365,6 @@ def flux_to_flareclass(goesflux):
         str_class = "X"
         decade = -4
     else:
-        str_class = conversion_dict.get(u.Quantity(10 ** decade, "W/m**2" ))
+        str_class = conversion_dict.get(u.Quantity(10 ** decade, "W/m**2"))
     goes_subclass = 10 ** -decade * goesflux.to('W/m**2').value
     return "{0}{1:.3g}".format(str_class, goes_subclass)
