@@ -14,12 +14,12 @@ import pandas
 from sunpy.time import parse_time
 from sunpy import config
 from sunpy.util.net import check_download_file
+from sunpy.util.config import get_and_create_download_dir
 from sunpy import lightcurve
 
 from sunpy.extern.six.moves import urllib
 
 LYTAF_REMOTE_PATH = "http://proba2.oma.be/lyra/data/lytaf/"
-LYTAF_PATH = config.get("downloads", "download_dir")
 
 
 def remove_lytaf_events_from_lightcurve(lc, artifacts=None,
@@ -94,7 +94,7 @@ def remove_lytaf_events_from_lightcurve(lc, artifacts=None,
     """
     # Check that input argument is of correct type
     if not lytaf_path:
-        lytaf_path = LYTAF_PATH
+        lytaf_path = get_and_create_download_dir()
     if not isinstance(lc, lightcurve.LightCurve):
         raise TypeError("lc must be a LightCurve object.")
     # Remove artifacts from time series
@@ -115,6 +115,7 @@ def remove_lytaf_events_from_lightcurve(lc, artifacts=None,
     else:
         return lc_new
 
+
 def _remove_lytaf_events(time, channels=None, artifacts=None,
                          return_artifacts=False, fitsfile=None,
                          csvfile=None, filecolumns=None,
@@ -221,7 +222,7 @@ def _remove_lytaf_events(time, channels=None, artifacts=None,
     """
     # Check inputs
     if not lytaf_path:
-        lytaf_path = LYTAF_PATH
+        lytaf_path = get_and_create_download_dir()
     if channels and type(channels) is not list:
         raise TypeError("channels must be None or a list of numpy arrays "
                         "of dtype 'float64'.")
@@ -407,7 +408,7 @@ def get_lytaf_events(start_time, end_time, lytaf_path=None,
     # Check inputs
     # Check lytaf path
     if not lytaf_path:
-        lytaf_path = LYTAF_PATH
+        lytaf_path = get_and_create_download_dir()
     # Check start_time and end_time is a date string or datetime object
     start_time = parse_time(start_time)
     end_time = parse_time(end_time)
@@ -519,6 +520,7 @@ def get_lytaf_events(start_time, end_time, lytaf_path=None,
 
     return lytaf
 
+
 def get_lytaf_event_types(lytaf_path=None, print_event_types=True):
     """Prints the different event types in the each of the LYTAF databases.
 
@@ -526,7 +528,7 @@ def get_lytaf_event_types(lytaf_path=None, print_event_types=True):
     ----------
     lytaf_path : `str`
         Path location where LYTAF files are stored.
-        Default = LYTAF_PATH defined above.
+        Default = Path stored in confog file.
 
     print_event_types : `bool`
         If True, prints the artifacts in each lytaf database to screen.
@@ -539,7 +541,7 @@ def get_lytaf_event_types(lytaf_path=None, print_event_types=True):
     """
     # Set lytaf_path is not done by user
     if not lytaf_path:
-        lytaf_path = LYTAF_PATH
+        lytaf_path = get_and_create_download_dir()
     suffixes = ["lyra", "manual", "ppt", "science"]
     all_event_types = []
     # For each database file extract the event types and print them.
@@ -649,20 +651,21 @@ def split_series_using_lytaf(timearray, data, lytaf):
             # can't index h+1 here. Go to end of series
             subtimes = datetime_array[disc[h]:-1]
             subdata = data[disc[h]:-1]
-            subseries = {'subtimes':subtimes, 'subdata':subdata}
+            subseries = {'subtimes': subtimes, 'subdata': subdata}
             split_series.append(subseries)
         else:
             subtimes = datetime_array[disc[h]:disc[h+1]]
             subdata = data[disc[h]:disc[h+1]]
-            subseries = {'subtimes':subtimes, 'subdata':subdata}
+            subseries = {'subtimes': subtimes, 'subdata': subdata}
             split_series.append(subseries)
 
     return split_series
 
+
 def _lytaf_event2string(integers):
     if type(integers) == int:
         integers = [integers]
-    #else:
+    # else:
     #    n=len(integers)
     out = []
 
@@ -692,6 +695,7 @@ def _lytaf_event2string(integers):
 
     return out
 
+
 def _prep_columns(time, channels=None, filecolumns=None):
     """
     Checks and prepares data to be written out to a file.
