@@ -5,5 +5,5 @@ have its own file with one or more classes defined.
 """
 __all__ = ['CallistoSpectrogram', 'SWavesSpectrogram']
 
-from callisto import CallistoSpectrogram
-from swaves import SWavesSpectrogram
+from .callisto import CallistoSpectrogram
+from .swaves import SWavesSpectrogram
