@@ -4,6 +4,8 @@
 
 from __future__ import absolute_import, division, print_function
 import warnings
+import tempfile
+import platform
 
 import pytest
 import numpy as np
@@ -30,7 +32,6 @@ else:
         SKIP_GLYMUR = True
 
 # Skip ana tests if we are on Windows or we can't import the c extension.
-import platform
 if platform.system() == 'Windows':
     SKIP_ANA = True
 else:
@@ -45,7 +46,10 @@ else:
 
 
 try:
-    import wcsaxes
+    try:
+        from astropy.visualization import wcsaxes
+    except ImportError:
+        import wcsaxes
 except ImportError:
     SKIP_WCSAXES = True
 else:
@@ -65,7 +69,6 @@ def warnings_as_errors(request):
 
     request.addfinalizer(lambda *args: warnings.resetwarnings())
 
-
 def assert_quantity_allclose(actual, desired, rtol=1.e-7, atol=0, err_msg='', verbose=True):
     """
     Raise an assertion if two objects are not equal up to desired tolerance.
@@ -99,11 +102,17 @@ def assert_quantity_allclose(actual, desired, rtol=1.e-7, atol=0, err_msg='', ve
         np.testing.assert_allclose(actual, desired,
                                    rtol=rtol, atol=atol, err_msg=err_msg, verbose=verbose)
 
+new_hash_library = {}
+
+figure_test_pngfiles = {}
+
 
 def figure_test(test_function):
     """
     A decorator for a test that verifies the hash of the current figure or the returned figure,
     with the name of the test function as the hash identifier in the library.
+    A PNG is also created with a temporary filename, with the lookup stored in the
+    `figure_test_pngfiles` dictionary.
 
     All such decorated tests are marked with `pytest.mark.figure` for convenient filtering.
 
@@ -118,9 +127,12 @@ def figure_test(test_function):
     def wrapper(*args, **kwargs):
         plt.figure()
         name = "{0}.{1}".format(test_function.__module__, test_function.__name__)
-        figure_hash = hash.hash_figure(test_function(*args, **kwargs))
+        pngfile = tempfile.NamedTemporaryFile(delete=False)
+        figure_hash = hash.hash_figure(test_function(*args, **kwargs), out_stream=pngfile)
+        figure_test_pngfiles[name] = pngfile.name
+        pngfile.close()
+        new_hash_library[name] = figure_hash
         if name not in hash.hash_library:
-            hash.hash_library[name] = figure_hash
             pytest.fail("Hash not present: {0}".format(name))
         else:
             assert hash.hash_library[name] == figure_hash
