@@ -43,7 +43,7 @@ def test_parse_time_pandas_timestamp():
 
 def test_parse_time_pandas_index():
     inputs = [datetime(2012, 1, i) for i in range(1,13)]
-    ind = pandas.tseries.index.DatetimeIndex(inputs)
+    ind = pandas.DatetimeIndex(inputs)
 
     dts = parse_time(ind)
 
@@ -131,4 +131,3 @@ def test_day_of_year():
     assert time.day_of_year('2012/04/10') == 101
     assert time.day_of_year('2012/01/31') == 31
     assert time.day_of_year('2012/09/30') == 274
-
